summaryrefslogtreecommitdiffstats
path: root/sys/cam
diff options
context:
space:
mode:
authorken <ken@FreeBSD.org>1999-03-07 22:48:50 +0000
committerken <ken@FreeBSD.org>1999-03-07 22:48:50 +0000
commitebc79d094efad3b20d8922b2f145e7db4fa12881 (patch)
tree30e796f5d8f1e3fc03fd9a2cc57b4a4017ef0d8c /sys/cam
parentb16da6db457a4fb8f9ff205d41ba7f148df56ced (diff)
downloadFreeBSD-src-ebc79d094efad3b20d8922b2f145e7db4fa12881.zip
FreeBSD-src-ebc79d094efad3b20d8922b2f145e7db4fa12881.tar.gz
The 4 gig version of the Seagate Medalist Pro seems to have the same
trouble with tagged queueing as the 6.5 gig version. So, I've added a quirk entry for it to limit it to two outstanding transactions at a time, just like the 6.5G version. While I'm at it, add a quirk for the 9G version of the drive, since it most likely has the same problem. Submitted by: Jeremy Lea <reg@shale.csir.co.za>
Diffstat (limited to 'sys/cam')
-rw-r--r--sys/cam/cam_xpt.c26
1 files changed, 21 insertions, 5 deletions
diff --git a/sys/cam/cam_xpt.c b/sys/cam/cam_xpt.c
index 77509a5..977003d 100644
--- a/sys/cam/cam_xpt.c
+++ b/sys/cam/cam_xpt.c
@@ -26,7 +26,7 @@
* OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGE.
*
- * $Id: cam_xpt.c,v 1.45 1999/02/26 18:38:06 ken Exp $
+ * $Id: cam_xpt.c,v 1.46 1999/03/05 23:18:16 gibbs Exp $
*/
#include <sys/param.h>
#include <sys/systm.h>
@@ -308,18 +308,34 @@ static struct xpt_quirk_entry xpt_quirk_table[] =
{ T_DIRECT, SIP_MEDIA_FIXED, seagate, "ST410800*", "71*" },
/*quirks*/0, /*mintags*/0, /*maxtags*/0
},
- {
/*
* Broken tagged queueing drive. (Write performance is
* very bad with anything more than 2 tags.
*
* Reported by: Paul van der Zwan <paulz@trantor.xs4all.nl>
* Drive: <SEAGATE ST36530N 1444>
+ *
+ * Reported by: Jeremy Lea <reg@shale.csir.co.za>
+ * Drive: <SEAGATE ST34520W 1281>
+ *
+ * No one has actually reported that the 9G version
+ * (ST39140*) of the Medalist Pro has the same problem, but
+ * we're assuming that it does because the 4G and 6.5G
+ * versions of the drive are broken.
*/
+ {
+ { T_DIRECT, SIP_MEDIA_FIXED, seagate, "ST34520*", "*"},
+ /*quirks*/0, /*mintags*/2, /*maxtags*/2
+ },
+ {
{ T_DIRECT, SIP_MEDIA_FIXED, seagate, "ST36530*", "*"},
/*quirks*/0, /*mintags*/2, /*maxtags*/2
},
{
+ { T_DIRECT, SIP_MEDIA_FIXED, seagate, "ST39140*", "*"},
+ /*quirks*/0, /*mintags*/2, /*maxtags*/2
+ },
+ {
/* Broken tagged queuing drive */
{ T_DIRECT, SIP_MEDIA_REMOVABLE, "iomega", "jaz*", "*" },
/*quirks*/0, /*mintags*/0, /*maxtags*/0
@@ -308,18 +308,34 @@ static struct xpt_quirk_entry xpt_quirk_table[] =
/*
- * Broken tagged queueing drive. (Write performance is
- * very bad with anything more than 2 tags.
- *
+ * The Seagate Medalist Pro drives have very poor write
+ * performance with anything more than 2 tags.
+ *
* Reported by: Paul van der Zwan <paulz@trantor.xs4all.nl>
* Drive: <SEAGATE ST36530N 1444>
OpenPOWER on IntegriCloud